Iterative Algorithms (`sigpy.alg`)
==================================

.. automodule::
   sigpy.alg


The Algorithm Class
-------------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.alg.Alg

First-order Gradient Methods
----------------------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.alg.GradientMethod
   sigpy.alg.ConjugateGradient
   sigpy.alg.PrimalDualHybridGradient
   sigpy.alg.ADMM
   sigpy.alg.SDMM


Other Methods
-------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.alg.NewtonsMethod
   sigpy.alg.PowerMethod
   sigpy.alg.AltMin
   sigpy.alg.AugmentedLagrangianMethod
